Struct moonramp_entity::program::Entity
source · [−]pub struct Entity;Trait Implementations
sourceimpl EntityName for Entity
impl EntityName for Entity
sourcefn schema_name(&self) -> Option<&str>
fn schema_name(&self) -> Option<&str>
Method to get the name for the schema, defaults to Option::None if not set
sourcefn table_name(&self) -> &str
fn table_name(&self) -> &str
Get the name of the table
fn module_name(&self) -> &str
fn module_name(&self) -> &str
Get the name of the module from the invoking self.table_name()
fn table_ref(&self) -> TableRef
fn table_ref(&self) -> TableRef
Get the [TableRef] from invoking the self.schema_name()
sourceimpl EntityTrait for Entity
impl EntityTrait for Entity
type Model = Model
type Column = Column
type PrimaryKey = PrimaryKey
type Relation = Relation
fn belongs_to<R>(related: R) -> RelationBuilder<Self, R> where
R: EntityTrait,
fn belongs_to<R>(related: R) -> RelationBuilder<Self, R> where
R: EntityTrait,
Check if the relation belongs to an Entity
fn has_one<R>(R) -> RelationBuilder<Self, R> where
R: EntityTrait + Related<Self>,
fn has_one<R>(R) -> RelationBuilder<Self, R> where
R: EntityTrait + Related<Self>,
Check if the entity has at least one relation
fn has_many<R>(R) -> RelationBuilder<Self, R> where
R: EntityTrait + Related<Self>,
fn has_many<R>(R) -> RelationBuilder<Self, R> where
R: EntityTrait + Related<Self>,
Check if the Entity has many relations
fn find_by_id(
values: <Self::PrimaryKey as PrimaryKeyTrait>::ValueType
) -> Select<Self>
fn find_by_id(
values: <Self::PrimaryKey as PrimaryKeyTrait>::ValueType
) -> Select<Self>
Find a model by primary key Read more
fn insert<A>(model: A) -> Insert<A> where
A: ActiveModelTrait<Entity = Self>,
fn insert<A>(model: A) -> Insert<A> where
A: ActiveModelTrait<Entity = Self>,
Insert an model into database Read more
fn insert_many<A, I>(models: I) -> Insert<A> where
A: ActiveModelTrait<Entity = Self>,
I: IntoIterator<Item = A>,
fn insert_many<A, I>(models: I) -> Insert<A> where
A: ActiveModelTrait<Entity = Self>,
I: IntoIterator<Item = A>,
Insert many models into database Read more
fn update<A>(model: A) -> UpdateOne<A> where
A: ActiveModelTrait<Entity = Self>,
fn update<A>(model: A) -> UpdateOne<A> where
A: ActiveModelTrait<Entity = Self>,
Update an model in database Read more
fn update_many() -> UpdateMany<Self>
fn update_many() -> UpdateMany<Self>
Update many models in database Read more
fn delete<A>(model: A) -> DeleteOne<A> where
A: ActiveModelTrait<Entity = Self>,
fn delete<A>(model: A) -> DeleteOne<A> where
A: ActiveModelTrait<Entity = Self>,
Delete an model from database Read more
fn delete_many() -> DeleteMany<Self>
fn delete_many() -> DeleteMany<Self>
Delete many models from database Read more
fn delete_by_id(
values: <Self::PrimaryKey as PrimaryKeyTrait>::ValueType
) -> DeleteMany<Self>
fn delete_by_id(
values: <Self::PrimaryKey as PrimaryKeyTrait>::ValueType
) -> DeleteMany<Self>
Delete a model based on primary key Read more
sourceimpl From<<Entity as EntityTrait>::Model> for ActiveModel
impl From<<Entity as EntityTrait>::Model> for ActiveModel
impl Copy for Entity